@@ -6,23 +6,31 @@ import (
 	"io"
 	"os"
 	"path/filepath"
-	"time"
 
 	"github.com/sirupsen/logrus"
 	"github.com/urfave/cli"
 
 	"gitlab.com/gitlab-org/gitlab-runner/common"
 	"gitlab.com/gitlab-org/gitlab-runner/helpers/archives"
+	"gitlab.com/gitlab-org/gitlab-runner/helpers/retry"
 	"gitlab.com/gitlab-org/gitlab-runner/log"
 	"gitlab.com/gitlab-org/gitlab-runner/network"
 )
 
-const DefaultUploadName = "default"
+const (
+	DefaultUploadName       = "default"
+	defaultTries            = 3
+	serviceUnavailableTries = 6
+)
+
+var (
+	errServiceUnavailable = errors.New("service unavailable")
+	errTooLarge           = errors.New("too large")
+)
 
 type ArtifactsUploaderCommand struct {
 	common.JobCredentials
 	fileArchiver
-	retryHelper
 	network common.Network
 
 	Name     string                `long:"name" description:"The name of the archive"`
@@ -83,7 +91,7 @@ func (c *ArtifactsUploaderCommand) createReadStream() (string, io.ReadCloser, er
 	}
 }
 
-func (c *ArtifactsUploaderCommand) createAndUpload() error {
+func (c *ArtifactsUploaderCommand) Run() error {
 	artifactsName, stream, err := c.createReadStream()
 	if err != nil {
 		return err
@@ -110,14 +118,34 @@ func (c *ArtifactsUploaderCommand) createAndUpload() error {
 	case common.UploadForbidden:
 		return os.ErrPermission
 	case common.UploadTooLarge:
-		return errors.New("too large")
+		return errTooLarge
 	case common.UploadFailed:
 		return retryableErr{err: os.ErrInvalid}
+	case common.UploadServiceUnavailable:
+		return retryableErr{err: errServiceUnavailable}
 	default:
 		return os.ErrInvalid
 	}
 }
 
+func (c *ArtifactsUploaderCommand) ShouldRetry(tries int, err error) bool {
+	var retryableErr retryableErr
+	if !errors.As(err, &retryableErr) {
+		return false
+	}
+
+	maxTries := defaultTries
+	if errors.Is(retryableErr, errServiceUnavailable) {
+		maxTries = serviceUnavailableTries
+	}
+
+	if tries >= maxTries {
+		return false
+	}
+
+	return true
+}
+
 func (c *ArtifactsUploaderCommand) Execute(*cli.Context) {
 	log.SetRunnerFormatter()
 
@@ -135,7 +163,9 @@ func (c *ArtifactsUploaderCommand) Execute(*cli.Context) {
 	}
 
 	// If the upload fails, exit with a non-zero exit code to indicate an issue?
-	err = c.doRetry(c.createAndUpload)
+	logger := logrus.WithField("context", "artifacts-uploader")
+	retryable := retry.New(retry.WithLogrus(c, logger))
+	err = retryable.Run()
 	if err != nil {
 		logrus.Fatalln(err)
 	}
@@ -144,10 +174,6 @@ func (c *ArtifactsUploaderCommand) Execute(*cli.Context) {
 func init() {
 	common.RegisterCommand2("artifacts-uploader", "create and upload build artifacts (internal)", &ArtifactsUploaderCommand{
 		network: network.NewGitLabClient(),
-		retryHelper: retryHelper{
-			Retry:     2,
-			RetryTime: time.Second,
-		},
-		Name: "artifacts",
+		Name:    "artifacts",
 	})
 }
