@@ -1,6 +1,7 @@
 package helpers
 
 import (
+	"errors"
 	"os"
 	"testing"
 
@@ -83,9 +84,6 @@ func TestArtifactsUploaderRetry(t *testing.T) {
 	cmd := ArtifactsUploaderCommand{
 		JobCredentials: UploaderCredentials,
 		network:        network,
-		retryHelper: retryHelper{
-			Retry: 2,
-		},
 		fileArchiver: fileArchiver{
 			Paths: []string{artifactsTestArchivedFile},
 		},
@@ -101,7 +99,7 @@ func TestArtifactsUploaderRetry(t *testing.T) {
 		cmd.Execute(nil)
 	})
 
-	assert.Equal(t, 3, network.uploadCalled)
+	assert.Equal(t, defaultTries, network.uploadCalled)
 }
 
 func TestArtifactsUploaderDefaultSucceeded(t *testing.T) {
@@ -254,3 +252,93 @@ func TestArtifactsUploaderNoFilesDoNotGenerateError(t *testing.T) {
 		cmd.Execute(nil)
 	})
 }
+
+func TestArtifactsUploaderServiceUnavailable(t *testing.T) {
+	network := &testNetwork{
+		uploadState: common.UploadServiceUnavailable,
+	}
+	cmd := ArtifactsUploaderCommand{
+		JobCredentials: UploaderCredentials,
+		network:        network,
+		fileArchiver: fileArchiver{
+			Paths: []string{artifactsTestArchivedFile},
+		},
+	}
+
+	writeTestFile(t, artifactsTestArchivedFile)
+	defer os.Remove(artifactsTestArchivedFile)
+
+	removeHook := helpers.MakeFatalToPanic()
+	defer removeHook()
+
+	assert.Panics(t, func() {
+		cmd.Execute(nil)
+	})
+
+	assert.Equal(t, serviceUnavailableTries, network.uploadCalled)
+}
+
+func TestArtifactUploaderCommandShouldRetry(t *testing.T) {
+	tests := map[string]struct {
+		err   error
+		tries int
+
+		expectedShouldRetry bool
+	}{
+		"no error, first try": {
+			err:   nil,
+			tries: 1,
+
+			expectedShouldRetry: false,
+		},
+		"random error, first try": {
+			err:   errors.New("err"),
+			tries: 1,
+
+			expectedShouldRetry: false,
+		},
+		"retryable error, first try": {
+			err:   retryableErr{},
+			tries: 1,
+
+			expectedShouldRetry: true,
+		},
+		"retryable error, max tries": {
+			err:   retryableErr{},
+			tries: defaultTries,
+
+			expectedShouldRetry: false,
+		},
+		"retryable error, over max tries limit": {
+			err:   retryableErr{},
+			tries: defaultTries + 10,
+
+			expectedShouldRetry: false,
+		},
+		"retryable error, before reaching service unavailable tries": {
+			err:   retryableErr{err: errServiceUnavailable},
+			tries: serviceUnavailableTries - 1,
+
+			expectedShouldRetry: true,
+		},
+		"retryable error service unavailable, max tries": {
+			err:   retryableErr{err: errServiceUnavailable},
+			tries: serviceUnavailableTries,
+
+			expectedShouldRetry: false,
+		},
+		"retryable error service unavailable, over max errors limit": {
+			err:   retryableErr{err: errServiceUnavailable},
+			tries: serviceUnavailableTries + 10,
+
+			expectedShouldRetry: false,
+		},
+	}
+
+	for tn, tt := range tests {
+		t.Run(tn, func(t *testing.T) {
+			r := ArtifactsUploaderCommand{}
+			assert.Equal(t, tt.expectedShouldRetry, r.ShouldRetry(tt.tries, tt.err))
+		})
+	}
+}
