@@ -78,6 +78,19 @@ func TestBuildRun(t *testing.T) {
 }
 
 func TestBuildPredefinedVariables(t *testing.T) {
+	for _, rootDir := range []string{"/root/dir1", "/root/dir2"} {
+		t.Run(rootDir, func(t *testing.T) {
+			build := runSuccessfulMockBuild(t, func(options ExecutorPrepareOptions) error {
+				return options.Build.StartBuild(rootDir, "/cache/dir", false, false)
+			})
+
+			projectDir := build.GetAllVariables().Get("CI_PROJECT_DIR")
+			assert.NotEmpty(t, projectDir, "should have CI_PROJECT_DIR")
+		})
+	}
+}
+
+func runSuccessfulMockBuild(t *testing.T, prepareFn func(options ExecutorPrepareOptions) error) *Build {
 	e := MockExecutor{}
 	defer e.AssertExpectations(t)
 
@@ -92,11 +105,7 @@ func TestBuildPredefinedVariables(t *testing.T) {
 	p.On("Create").Return(&e).Once()
 
 	// We run everything once
-	e.On("Prepare", mock.Anything).
-		Return(func(options ExecutorPrepareOptions) error {
-			options.Build.StartBuild("/root/dir", "/cache/dir", false, false)
-			return nil
-		}).Once()
+	e.On("Prepare", mock.Anything).Return(prepareFn).Once()
 	e.On("Finish", nil).Return().Once()
 	e.On("Cleanup").Return().Once()
 
@@ -126,8 +135,56 @@ func TestBuildPredefinedVariables(t *testing.T) {
 	err = build.Run(&Config{}, &Trace{Writer: os.Stdout})
 	assert.NoError(t, err)
 
-	projectDir := build.GetAllVariables().Get("CI_PROJECT_DIR")
-	assert.NotEmpty(t, projectDir, "should have CI_PROJECT_DIR")
+	return build
+}
+
+func TestJobImageExposed(t *testing.T) {
+	tests := map[string]struct {
+		image           string
+		vars            []JobVariable
+		expectVarExists bool
+		expectImageName string
+	}{
+		"normal image exposed": {
+			image:           "alpine:3.11",
+			expectVarExists: true,
+			expectImageName: "alpine:3.11",
+		},
+		"image with variable expansion": {
+			image:           "${IMAGE}:3.11",
+			vars:            []JobVariable{{Key: "IMAGE", Value: "alpine", Public: true}},
+			expectVarExists: true,
+			expectImageName: "alpine:3.11",
+		},
+		"no image specified": {
+			image:           "",
+			expectVarExists: false,
+		},
+	}
+
+	for name, tt := range tests {
+		t.Run(name, func(t *testing.T) {
+			build := runSuccessfulMockBuild(t, func(options ExecutorPrepareOptions) error {
+				options.Build.Image.Name = tt.image
+				options.Build.Variables = append(options.Build.Variables, tt.vars...)
+				return options.Build.StartBuild("/root/dir", "/cache/dir", false, false)
+			})
+
+			actualVarExists := false
+			for _, v := range build.GetAllVariables() {
+				if v.Key == "CI_JOB_IMAGE" {
+					actualVarExists = true
+					break
+				}
+			}
+			assert.Equal(t, tt.expectVarExists, actualVarExists, "CI_JOB_IMAGE exported?")
+
+			if tt.expectVarExists {
+				actualJobImage := build.GetAllVariables().Get("CI_JOB_IMAGE")
+				assert.Equal(t, tt.expectImageName, actualJobImage)
+			}
+		})
+	}
 }
 
 func TestBuildRunNoModifyConfig(t *testing.T) {
@@ -948,14 +1005,14 @@ func TestAllowToOverwriteFeatureFlagWithRunnerVariables(t *testing.T) {
 	}{
 		"it has default value of FF": {
 			variable:      "",
-			expectedValue: true,
+			expectedValue: false,
 		},
 		"it enables FF": {
-			variable:      "FF_K8S_USE_ENTRYPOINT_OVER_COMMAND=true",
+			variable:      "FF_USE_LEGACY_VOLUMES_MOUNTING_ORDER=true",
 			expectedValue: true,
 		},
 		"it disable FF": {
-			variable:      "FF_K8S_USE_ENTRYPOINT_OVER_COMMAND=false",
+			variable:      "FF_USE_LEGACY_VOLUMES_MOUNTING_ORDER=false",
 			expectedValue: false,
 		},
 	}
@@ -969,7 +1026,7 @@ func TestAllowToOverwriteFeatureFlagWithRunnerVariables(t *testing.T) {
 				},
 			}
 
-			result := build.IsFeatureFlagOn("FF_K8S_USE_ENTRYPOINT_OVER_COMMAND")
+			result := build.IsFeatureFlagOn("FF_USE_LEGACY_VOLUMES_MOUNTING_ORDER")
 			assert.Equal(t, test.expectedValue, result)
 		})
 	}
@@ -1362,3 +1419,37 @@ func TestDefaultVariables(t *testing.T) {
 		})
 	}
 }
+
+func TestBuildFinishTimeout(t *testing.T) {
+	tests := map[string]bool{
+		"channel returns first": true,
+		"timeout returns first": false,
+	}
+
+	for name, chanFirst := range tests {
+		t.Run(name, func(t *testing.T) {
+			logger, hooks := test.NewNullLogger()
+			build := Build{
+				logger: NewBuildLogger(nil, logrus.NewEntry(logger)),
+			}
+			buildFinish := make(chan error, 1)
+			timeout := 10 * time.Millisecond
+
+			if chanFirst {
+				buildFinish <- errors.New("job finish error")
+			}
+
+			build.waitForBuildFinish(buildFinish, timeout)
+
+			entry := hooks.LastEntry()
+
+			if chanFirst {
+				assert.Nil(t, entry)
+				return
+			}
+
+			assert.NotNil(t, entry)
+		})
+	}
+
+}
