@@ -6,16 +6,11 @@ const DefaultTimeout = 7200
 const DefaultExecTimeout = 1800
 const CheckInterval = 3 * time.Second
 const NotHealthyCheckInterval = 300
-const UpdateInterval = 3 * time.Second
-const UpdateRetryInterval = 3 * time.Second
 const ReloadConfigInterval = 3
 const HealthyChecks = 3
 const HealthCheckInterval = 3600
 const DefaultWaitForServicesTimeout = 30
 const ShutdownTimeout = 30
-const DefaultOutputLimit = 4 * 1024 * 1024 // in bytes
-const DefaultTracePatchLimit = 1024 * 1024 // in bytes
-const ForceTraceSentInterval = 30 * time.Second
 const PreparationRetries = 3
 const DefaultGetSourcesAttempts = 1
 const DefaultArtifactDownloadAttempts = 1
@@ -29,6 +24,14 @@ const DefaultNetworkClientTimeout = 60 * time.Minute
 const DefaultSessionTimeout = 30 * time.Minute
 const WaitForBuildFinishTimeout = 5 * time.Minute
 
+const (
+	DefaultTraceOutputLimit    = 4 * 1024 * 1024 // in bytes
+	DefaultTracePatchLimit     = 1024 * 1024     // in bytes
+	DefaultTraceUpdateInterval = 3 * time.Second
+	TraceFinishRetryInterval   = 3 * time.Second
+	TraceForceSendInterval     = 30 * time.Second
+)
+
 var PreparationRetryInterval = 3 * time.Second
 
 const (
