@@ -8,6 +8,8 @@ const (
 	CmdDisableDelayedErrorLevelExpansion string = "FF_CMD_DISABLE_DELAYED_ERROR_LEVEL_EXPANSION"
 	UseLegacyBuildsDirForDocker          string = "FF_USE_LEGACY_BUILDS_DIR_FOR_DOCKER"
 	UseLegacyVolumesMountingOrder        string = "FF_USE_LEGACY_VOLUMES_MOUNTING_ORDER"
+	NetworkPerBuild                      string = "FF_NETWORK_PER_BUILD"
+	UseLegacyKubernetesExecutionStrategy string = "FF_USE_LEGACY_KUBERNETES_EXECUTION_STRATEGY"
 )
 
 type FeatureFlag struct {
@@ -31,6 +33,13 @@ var flags = []FeatureFlag{
 		ToBeRemovedWith: "13.0",
 		Description:     "Disables [EnableDelayedExpansion](https://ss64.com/nt/delayedexpansion.html) for error checking for when using [Window Batch](https://docs.gitlab.com/runner/shells/#windows-batch) shell",
 	},
+	{
+		Name:            NetworkPerBuild,
+		DefaultValue:    "false",
+		Deprecated:      false,
+		ToBeRemovedWith: "",
+		Description:     "Enables creation of a docker [network per build](https://docs.gitlab.com/runner/executors/docker.html#networking) with the docker executor",
+	},
 	{
 		Name:            UseLegacyBuildsDirForDocker,
 		DefaultValue:    "false",
@@ -45,6 +54,13 @@ var flags = []FeatureFlag{
 		ToBeRemovedWith: "13.0",
 		Description:     "Disables the new ordering of volumes mounting when `docker*` executors are being used.",
 	},
+	{
+		Name:            UseLegacyKubernetesExecutionStrategy,
+		DefaultValue:    "true",
+		Deprecated:      false,
+		ToBeRemovedWith: "",
+		Description:     "When set to `false` disables execution of remote Kubernetes commands through `exec` in favor of `attach` to solve problems like [#4119](https://gitlab.com/gitlab-org/gitlab-runner/issues/4119)",
+	},
 }
 
 func GetAll() []FeatureFlag {
